@@ -1,4 +1,4 @@
-#![doc(html_root_url = "https://docs.rs/sarif-fmt/0.2.19")]
+#![doc(html_root_url = "https://docs.rs/sarif-fmt/0.2.20")]
 #![recursion_limit = "256"]
 //! # WARNING: VERY UNSTABLE (EARLY IMPLEMENTATION)
 //!
@@ -608,8 +608,8 @@ fn to_writer_plain(sarif: &sarif::Sarif) -> Result<()> {
 
     diagnostics.iter().for_each(|diagnostic| {
       println!(
-        "{} [{}:{}:{}] {}",
-        diagnostic.1, diagnostic.0, diagnostic.2, diagnostic.3, diagnostic.4
+        "{}:{}:{}: {}: {}",
+        diagnostic.0, diagnostic.2, diagnostic.3, diagnostic.1, diagnostic.4
       )
     });
     Ok(())
@@ -761,26 +761,26 @@ fn to_writer_pretty(sarif: &sarif::Sarif) -> Result<()> {
 
 fn main() -> Result<()> {
   let matches = App::new("sarif-fmt")
-        .about("Pretty print SARIF results")
-        .after_help(
-            "The expected input is generated by running 'cargo clippy --message-format=json'.",
-        )
-        .version(env!("CARGO_PKG_VERSION"))
-
-        .arg(
-          Arg::new("message format").about("One of plain or pretty")
-            .default_value("pretty")
-            .short('f')
-            .long("message-format")
-            .value_name("FMT")
-            .takes_value(true)
-        )
-        .arg(
-            Arg::new("input")
-                .about("input file; reads from stdin if none is given")
-                .takes_value(true),
-        )
-        .get_matches();
+    .about("Pretty print SARIF results")
+    .after_help(
+      "The expected input is a SARIF file (ex. cat foo.sarif | sarif-fmt).",
+    )
+    .version(env!("CARGO_PKG_VERSION"))
+    .arg(
+      Arg::new("message format")
+        .about("One of plain or pretty")
+        .default_value("pretty")
+        .short('f')
+        .long("message-format")
+        .value_name("FMT")
+        .takes_value(true),
+    )
+    .arg(
+      Arg::new("input")
+        .about("input file; reads from stdin if none is given")
+        .takes_value(true),
+    )
+    .get_matches();
 
   let read = match matches.value_of_os("input").map(Path::new) {
     Some(path) => Box::new(File::open(path)?) as Box<dyn Read>,
